@@ -18,6 +18,7 @@ from .ceil import ceil
 from .choose import choose
 from .common_type import common_type
 from .concatenate import concatenate
+from .count_nonzero import count_nonzero
 from .cumsum import cumsum
 from .divide import divide
 from .dsplit import dsplit
@@ -37,6 +38,7 @@ from .mean import mean
 from .moveaxis import moveaxis
 from .multiply import multiply
 from .negative import negative
+from .nonzero import nonzero
 from .not_equal import not_equal
 from .outer import outer
 from .positive import positive
